@@ -1,11 +1,14 @@
 #!/usr/bin/env python
 
-import ConfigParser
+try:
+    import ConfigParser as configparser
+except ImportError:
+    import configparser
 import datetime
 import os
 import os.path as osp
-import platform
 import pkg_resources
+import platform
 import re
 import shlex
 import shutil
@@ -13,6 +16,7 @@ import subprocess
 import sys
 
 import click
+import six
 
 
 __author__ = 'Kentaro Wada <www.kentaro.wada@gmail.com>'
@@ -51,22 +55,30 @@ def parse_todo(content):
             text = m.groups()[1]
             todos.append([text, done, section, ''])
         else:
-            todos[-1][3] += '\n' + line  # detail
+            todos[-1][3] += line  # detail
 
     date = date or datetime.date.today()
 
     return date, todos
 
 
-def render_todo(date, todos):
+def render_todo(date, todos, color=False):
+    date = date.strftime('# %Y-%m-%d')
+    if color:
+        date = click.style(date, 'green')
+
     todo = []
     for text, done, section, detail in todos:
         if section is not None:
+            if color:
+                section = click.style(section, 'blue')
             if section not in todo:
                 todo.append('')
                 todo.append(section)
                 todo.append('')
         cross = 'x' if done else ' '
+        if color and not done:
+            text = click.style(text, underline=True)
         todo.append('- [{:s}] {:s}'.format(cross, text))
         if detail:
             todo.append('')
@@ -75,17 +87,17 @@ def render_todo(date, todos):
     todo = '\n'.join(todo)
 
     content = '''\
-# {date}
+{date}
 {todo}
 '''
-    content = content.format(date=date.strftime('%Y-%m-%d'), todo=todo)
+    content = content.format(date=date, todo=todo)
 
     return content
 
 
 def _init(remote_url=None):
     global GITHUB_URL
-    config = ConfigParser.ConfigParser()
+    config = configparser.ConfigParser()
     if osp.exists(CONFIG_FILE):
         if remote_url:
             print('Config file already exists: {:s}'.format(CONFIG_FILE))
@@ -97,7 +109,7 @@ def _init(remote_url=None):
         if remote_url:
             GITHUB_URL = remote_url
         else:
-            GITHUB_URL = raw_input('Remote Git URL?: ')
+            GITHUB_URL = six.moves.input('Remote Git URL?: ')
         config.set('remote', 'url', GITHUB_URL)
         config.write(open(CONFIG_FILE, 'w'))
     print('Remote URL: {:s}'.format(GITHUB_URL))
@@ -212,8 +224,10 @@ def cmd_show():
     _archive()
     readme_fn = osp.join(CACHE_DIR, 'README.md')
     date, todos = parse_todo(open(readme_fn).read())
-    content = render_todo(date, todos)
-    print(content)
+    content = render_todo(date, todos, color=True)
+    if six.PY2:
+        content = content.decode('utf-8')
+    click.echo_via_pager(content, color=True)
 
 
 @cli.command('edit', help='Edit todo')
